@@ -19,8 +19,7 @@
  * along with this program.  If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * Contact the authors at <https://www.fukt.bsnet.se/~belorn/> and
- * <https://www.fukt.bsnet.se/~teddy/>.
+ * Contact the authors at <mandos@fukt.bsnet.se>.
  */
 
 #define _GNU_SOURCE		/* TEMP_FAILURE_RETRY() */
@@ -29,7 +28,7 @@
 #include <iso646.h>		/* and */
 #include <errno.h>		/* errno, EEXIST */
 #include <stdio.h>		/* perror() */
-#include <stdlib.h>		/* EXIT_FAILURE, NULL, size_t, free(), 
+#include <stdlib.h>		/* EXIT_FAILURE, NULL, size_t, free(),
 				   realloc(), EXIT_SUCCESS */
 #include <fcntl.h>		/* open(), O_RDONLY */
 #include <unistd.h>		/* read(), close(), write(),
@@ -43,14 +42,14 @@ int main(__attribute__((unused))int argc,
   
   /* Create FIFO */
   const char passfifo[] = "/lib/cryptsetup/passfifo";
-  ret = (int)TEMP_FAILURE_RETRY(mkfifo(passfifo, S_IRUSR | S_IWUSR));
+  ret = mkfifo(passfifo, S_IRUSR | S_IWUSR);
   if(ret == -1 and errno != EEXIST){
     perror("mkfifo");
     return EXIT_FAILURE;
   }
   
   /* Open FIFO */
-  int fifo_fd = (int)TEMP_FAILURE_RETRY(open(passfifo, O_RDONLY));
+  int fifo_fd = open(passfifo, O_RDONLY);
   if(fifo_fd == -1){
     perror("open");
     return EXIT_FAILURE;
@@ -62,7 +61,7 @@ int main(__attribute__((unused))int argc,
   {
     size_t buf_allocated = 0;
     const size_t blocksize = 1024;
-    do{
+    do {
       if(buf_len + blocksize > buf_allocated){
 	char *tmp = realloc(buf, buf_allocated + blocksize);
 	if(tmp == NULL){
@@ -73,25 +72,23 @@ int main(__attribute__((unused))int argc,
 	buf = tmp;
 	buf_allocated += blocksize;
       }
-      sret = TEMP_FAILURE_RETRY(read(fifo_fd, buf + buf_len,
-				     buf_allocated - buf_len));
+      sret = read(fifo_fd, buf + buf_len, buf_allocated - buf_len);
       if(sret == -1){
 	perror("read");
 	free(buf);
 	return EXIT_FAILURE;
       }
       buf_len += (size_t)sret;
-    }while(sret != 0);
+    } while(sret != 0);
   }
   
   /* Close FIFO */
-  TEMP_FAILURE_RETRY(close(fifo_fd));
+  close(fifo_fd);
   
   /* Print password to stdout */
   size_t written = 0;
   while(written < buf_len){
-    sret = TEMP_FAILURE_RETRY(write(STDOUT_FILENO, buf + written,
-				    buf_len - written));
+    sret = write(STDOUT_FILENO, buf + written, buf_len - written);
     if(sret == -1){
       perror("write");
       free(buf);
