@@ -1,4 +1,4 @@
-/*  -*- coding: utf-8 -*- */
+/*  -*- coding: utf-8; mode: c; mode: orgtbl -*- */
 /*
  * Password-prompt - Read a password from the terminal and print it
  * 
@@ -19,8 +19,7 @@
  * along with this program.  If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * Contact the authors at <https://www.fukt.bsnet.se/~belorn/> and
- * <https://www.fukt.bsnet.se/~teddy/>.
+ * Contact the authors at <mandos@fukt.bsnet.se>.
  */
 
 #define _GNU_SOURCE		/* getline() */
@@ -33,7 +32,8 @@
 #include <signal.h>		/* sig_atomic_t, raise(), struct
 				   sigaction, sigemptyset(),
 				   sigaction(), sigaddset(), SIGINT,
-				   SIGQUIT, SIGHUP, SIGTERM */
+				   SIGQUIT, SIGHUP, SIGTERM,
+				   raise() */
 #include <stddef.h>		/* NULL, size_t, ssize_t */
 #include <sys/types.h>		/* ssize_t */
 #include <stdlib.h>		/* EXIT_SUCCESS, EXIT_FAILURE,
@@ -52,12 +52,17 @@
 				   ARGP_ERR_UNKNOWN */
 
 volatile sig_atomic_t quit_now = 0;
+int signal_received;
 bool debug = false;
 const char *argp_program_version = "password-prompt " VERSION;
 const char *argp_program_bug_address = "<mandos@fukt.bsnet.se>";
 
-static void termination_handler(__attribute__((unused))int signum){
+static void termination_handler(int signum){
+  if(quit_now){
+    return;
+  }
   quit_now = 1;
+  signal_received = signum;
 }
 
 int main(int argc, char **argv){
@@ -123,9 +128,25 @@ int main(int argc, char **argv){
   }
   
   sigemptyset(&new_action.sa_mask);
-  sigaddset(&new_action.sa_mask, SIGINT);
-  sigaddset(&new_action.sa_mask, SIGHUP);
-  sigaddset(&new_action.sa_mask, SIGTERM);
+  ret = sigaddset(&new_action.sa_mask, SIGINT);
+  if(ret == -1){
+    perror("sigaddset");
+    return EXIT_FAILURE;
+  }
+  ret = sigaddset(&new_action.sa_mask, SIGHUP);
+  if(ret == -1){
+    perror("sigaddset");
+    return EXIT_FAILURE;
+  }
+  ret = sigaddset(&new_action.sa_mask, SIGTERM);
+  if(ret == -1){
+    perror("sigaddset");
+    return EXIT_FAILURE;
+  }
+  /* Need to check if the handler is SIG_IGN before handling:
+     | [[info:libc:Initial Signal Actions]] |
+     | [[info:libc:Basic Signal Handling]]  |
+  */
   ret = sigaction(SIGINT, NULL, &old_action);
   if(ret == -1){
     perror("sigaction");
@@ -194,7 +215,7 @@ int main(int argc, char **argv){
       const char *cryptsource = getenv("cryptsource");
       const char *crypttarget = getenv("crypttarget");
       const char *const prompt
-	= "Enter passphrase to unlock the disk";      
+	= "Enter passphrase to unlock the disk";
       if(cryptsource == NULL){
 	if(crypttarget == NULL){
 	  fprintf(stderr, "%s: ", prompt);
@@ -242,7 +263,7 @@ int main(int argc, char **argv){
     /* if(ret == 0), then the only sensible thing to do is to retry to
        read from stdin */
     fputc('\n', stderr);
-    if(debug and quit_now == 0){
+    if(debug and not quit_now){
       /* If quit_now is nonzero, we were interrupted by a signal, and
 	 will print that later, so no need to show this too. */
       fprintf(stderr, "getline() returned 0, retrying.\n");
@@ -258,6 +279,16 @@ int main(int argc, char **argv){
     perror("tcsetattr+echo");
   }
   
+  if(quit_now){
+    sigemptyset(&old_action.sa_mask);
+    old_action.sa_handler = SIG_DFL;
+    ret = sigaction(signal_received, &old_action, NULL);
+    if(ret == -1){
+      perror("sigaction");
+    }
+    raise(signal_received);
+  }
+  
   if(debug){
     fprintf(stderr, "%s is exiting with status %d\n", argv[0],
 	    status);
